@@ -1,10 +1,10 @@
-# Plot method for Boruta
+# Plot method for Boruta.
 # Author: Miron B. Kursa
 ###############################################################################
 
 ##plot.Boruta draws ZScores obtained during process as boxplots and final decision as their colours.
 plot.Boruta<-function(x,colCode=c('green','yellow','red','blue'),sort=TRUE,whichRand=c(TRUE,TRUE,TRUE),
-		col=NULL,xlab='Attributes',ylab='Z-Score',...){
+		col=NULL,xlab='Attributes',ylab='Z-Scores',...){
 	#Checking arguments
 	if(class(x)!='Boruta') stop('This function needs Boruta object as an argument.')
 	if(is.null(col) & length(colCode)!=4) stop('colCode should have 4 elements.')
